"use strict";
import { __assign } from "tslib";
import { runPlugins, runPlugin, runMutation, runExtractor } from "../plugins";
import { pluginSource, testPluginNoOptions, testPluginWithOptions, blankPlugin, pluginType, testMarkdown, testMutationPlugin, testExtractorPlugin, trimSourceToThisChars, testDataWithOptionsString, returnObjectInExtractorPlugin, } from "./mocks";
describe("Plugins tests", function () {
    describe("runPlugin", function () {
        test("should run plugin with NO config", function () {
            var testPluginData = pluginSource();
            var testData = runPlugin(testPluginData, testPluginNoOptions(pluginType));
            var correct = {
                source: __assign({ data: {
                        data: testMarkdown,
                        testData: returnObjectInExtractorPlugin,
                    } }, pluginSource().source),
            };
            expect(testData).toEqual(correct);
        });
        test("should run plugin with config", function () {
            var testPluginData = pluginSource();
            var testData = runPlugin(testPluginData, testPluginWithOptions(pluginType));
            var correct = {
                source: __assign({ data: {
                        src: testMarkdown.slice(0, trimSourceToThisChars),
                        testDataWithOptions: testDataWithOptionsString,
                    } }, pluginSource().source),
            };
            expect(testData).toEqual(correct);
        });
        test("should return source if source-plugin sourceTypes do not match", function () {
            var testPluginData = pluginSource();
            var typeThatDiffersBetweenSourceAndPlugin = pluginType
                .split("")
                .reverse()
                .join("") + "randomString";
            var testData = runPlugin(testPluginData, blankPlugin(typeThatDiffersBetweenSourceAndPlugin));
            expect(testData).toEqual(pluginSource());
        });
    });
    describe("runMutation", function () {
        test("should return unmutated data when no options are specified", function () {
            var testPluginData = pluginSource();
            var testData = runMutation(testPluginData, testMutationPlugin);
            var correct = {
                source: __assign({ content: { testData: "testData", data: testMarkdown } }, pluginSource().source),
            };
            expect(testData).toEqual(correct);
        });
        test("should return mutated data when options are specified", function () {
            var testPluginData = pluginSource();
            var testData = runMutation(testPluginData, testMutationPlugin, {
                testOption: "testOption",
            });
            var correct = {
                source: __assign({ content: {
                        src: testMarkdown.slice(0, trimSourceToThisChars),
                        testData: testDataWithOptionsString,
                    } }, pluginSource().source),
            };
            expect(testData).toEqual(correct);
        });
    });
    describe("runExtractor", function () {
        test("should return mocked data in source field", function () {
            var testPluginData = pluginSource();
            var testData = runExtractor(testPluginData, testExtractorPlugin);
            var correct = {
                source: __assign({ data: { testData: returnObjectInExtractorPlugin, data: testMarkdown } }, pluginSource().source),
            };
            expect(testData).toEqual(correct);
        });
        test("should return correct data if options are specified", function () {
            var _a;
            var testPluginData = pluginSource();
            var testData = runExtractor(testPluginData, testExtractorPlugin, {
                testOption: true,
            });
            var correct = {
                source: __assign({ data: (_a = {},
                        _a[testDataWithOptionsString] = "testDataWithOptions",
                        _a.src = testMarkdown.slice(0, trimSourceToThisChars),
                        _a) }, pluginSource().source),
            };
            expect(testData).toEqual(correct);
        });
    });
    describe("runPlugins", function () {
        test("should return sources if no plugin is provided", function () {
            var pluginData = Array(10).fill(pluginSource());
            var testData = runPlugins(pluginData);
            var correct = Array(10).fill(pluginSource());
            expect(testData).toEqual(correct);
        });
        test("should return work without references", function () {
            var length = 10;
            var pluginData = Array(length).fill(pluginSource());
            var plugins = [
                testPluginNoOptions(pluginType),
                testPluginNoOptions(pluginType),
            ];
            var testData = runPlugins(pluginData, plugins);
            var correctItem = {
                source: __assign(__assign({}, pluginSource().source), { data: { data: testMarkdown, testData: returnObjectInExtractorPlugin } }),
            };
            var correct = Array(length).fill(correctItem);
            expect(testData).toEqual(correct); // we need to inline this to, because run* functions are not pure
        });
    });
});
